sensor_data = data_from_file();
IMU1 = [sensor_data.system_time, sensor_data.XGyro1, sensor_data.YGyro1, sensor_data.ZGyro1,...
    sensor_data.XAcc1, sensor_data.YAcc1, sensor_data.ZAcc1];
IMU2 = [sensor_data.system_time, sensor_data.XGyro2, sensor_data.YGyro2, sensor_data.ZGyro2,...
    sensor_data.XAcc2, sensor_data.YAcc2, sensor_data.ZAcc2];
IMU3 = [sensor_data.system_time, sensor_data.XGyro3, sensor_data.YGyro3, sensor_data.ZGyro3,...
    sensor_data.XAcc3, sensor_data.YAcc3, sensor_data.ZAcc3];
IMU4 = [sensor_data.system_time, sensor_data.XGyro4, sensor_data.YGyro4, sensor_data.ZGyro4,...
    sensor_data.XAcc4, sensor_data.YAcc4, sensor_data.ZAcc4];
titlelist = {'roll angular vel', 'pitch angular vel', ...
    'yaw angular vel', 'surge acc', 'sway acc', 'heave acc'};
GPS = [];
num_samplings = length(IMU1(:,1));

%% Aligning data with {b}
%Rotating positive directions of accelerations according to right-hand rule
IMU1(:,5:7) = -IMU1(:,5:7);
IMU2(:,5:7) = -IMU2(:,5:7);
IMU3(:,5:7) = -IMU3(:,5:7);
IMU4(:,5:7) = -IMU4(:,5:7);

%Assuming yaw angle is close to 0 or 180 degrees offset from ship yaw, the
%rotation matrix is set to
[J1, R1, T1] = eulerang(pi, 0, 0);
[J2, R2, T2] = eulerang(pi, -pi*7/72, 13*pi/360);
[J3, R3, T3] = eulerang(pi, 0, pi);
[J4, R4, T4] = eulerang(pi, 0, pi);

%Rotating all accelerations and rotations to align with body frame
for i = 1:num_samplings
    IMU1(i,2:4) = R1*IMU1(i,2:4)';
    IMU1(i,5:7) = R1*IMU1(i,5:7)';
    IMU2(i,2:4) = R2*IMU2(i,2:4)';
    IMU2(i,5:7) = R2*IMU2(i,5:7)';
    IMU3(i,2:4) = R3*IMU3(i,2:4)';
    IMU3(i,5:7) = R3*IMU3(i,5:7)';
    IMU4(i,2:4) = R4*IMU4(i,2:4)';
    IMU4(i,5:7) = R4*IMU4(i,5:7)';
end
%% Scale
% Scale acc sensor data from mg -> mm/s^2 -> m/s^2
IMU1(:,5:7) = IMU1(:,5:7).*9.81/1000;
IMU2(:,5:7) = IMU2(:,5:7).*9.81/1000;
IMU3(:,5:7) = IMU3(:,5:7).*9.81/1000;
IMU4(:,5:7) = IMU4(:,5:7).*9.81/1000;

%% Calculate and remove bias (inkl g)
b = [];
for i = 1:6
    b(1,i) = mean(IMU1(:,i+1));
    b(2,i) = mean(IMU2(:,i+1));
    b(3,i) = mean(IMU3(:,i+1));
    b(4,i) = mean(IMU4(:,i+1));
end
IMU1(:,2:7) = IMU1(:,2:7) - b(1,:);
IMU2(:,2:7) = IMU2(:,2:7) - b(2,:);
IMU3(:,2:7) = IMU3(:,2:7) - b(3,:); 
IMU4(:,2:7) = IMU4(:,2:7) - b(4,:);

% Low pass filtering
filt_data1 = filtering(IMU1, 2);
filt_data2 = filtering(IMU2, 2);
filt_data3 = filtering(IMU3, 2);
filt_data4 = filtering(IMU4, 2);

plotting(2, IMU1, IMU2, IMU3, IMU4, filt_data1, filt_data2, filt_data3, filt_data4, zeros(2), zeros(2), titlelist)

%% Sensor fusion
%[merged_a, merged_alpha] = IMU_sensor_fusion(filt_data1, filt_data2, filt_data3, filt_data4, num_samplings);

%plotting(3, IMU1, IMU2, IMU3, IMU4, filt_data1, filt_data2, filt_data3, filt_data4, merged_a, merged_alpha, titlelist)

