function cost = CFctr(x)
    
    %Set the newly found gains in the simulation model
    set_param('model_for_simulation/Simulation inputs/Constant2', 'Value', mat2str(diag(x(1:3))));
    
    Setpoints = [2, 0, 0;
                 0, -2, 0;
                 0, 0, -pi/4;
                 -2, 2, pi/4];
    eta_cost = 0;
    energy_cost = 0;
    tau_dot_cost = 0;

    for i=1:length(Setpoints)
        setpoint = Setpoints(i,:);
        set_param('model_for_simulation/Simulation inputs/Constant7', 'Value', mat2str(setpoint));
        %Simulate
        sim('model_for_simulation'); 
        
        load('results/eta.mat')
        load('results/eta_d.mat')
        load('results/nu.mat')
        load('results/tau.mat')
        
        %Get simulation data
        eta_d = eta_d.Data;
        eta = eta.Data;
        eta_e = eta - eta_d;
        nu = nu.Data;
        tau = tau.Data;
    
        %Max errors for calculating norms
        max_err = [2, 2, pi/2];
        max_tau = [3.6, 2, 1.7];
        max_nu = [0.4142, 0.109, 6.327*pi/180];

        %Calculate norms
        eta_e_norm = abs(eta_e)./max_err;
        tau_norm = abs(tau)./max_tau;
        tau_dot_norm = abs(diff(tau));
        nu_norm = abs(nu)./max_nu;
    
        eta_cost = eta_cost + sum(sum(eta_e_norm));
        energy_cost = energy_cost + sum(sum(tau_norm.*nu_norm));
        tau_dot_cost = tau_dot_cost + sum(sum(tau_dot_norm));
    end
    cost = eta_cost * tau_dot_cost;
    
    %write findings to file
    fileID = fopen('results/control_params.txt','a');
    fprintf(fileID,'%f %f %f %f %f %f %f\n', x', eta_cost, energy_cost, tau_dot_cost, cost);
    fclose(fileID);
    
end