function cost = CFobs(x)
    
    lambdaP = x(1);
    lambdaH = x(2);
    wc = x(3);
    Ts = x(4);
    KpP = x(5);
    KpH = x(6);
    
    % filter gains
    gamma = 90;
    wo = 0.68*sqrt(gamma);
    K11 = -2*(eye(3)-diag([lambdaP, lambdaP, lambdaH]))*(wc/wo);
    K12 = 2*(eye(3)-diag([lambdaP, lambdaP, lambdaH]))*wo;
    K2 = diag([wc, wc, wc]);
    K4 = diag([KpP, KpP, KpH]);
    T_b = Ts/sqrt(gamma);
    K3 = 10*(K4/T_b);
    T_b_inv = eye(3)*1/(T_b);
    Kw1 = 2*diag([lambdaP, lambdaP, lambdaH])*wo;
    Kw2 = wo*wo*eye(3);
    
    %Set the newly found gains in the simulation model
    set_param('model_for_simulation/Passive DP wave filter/obsK11', 'Gain', mat2str(K11));
    set_param('model_for_simulation/Passive DP wave filter/obsK12', 'Gain', mat2str(K12));
    set_param('model_for_simulation/Passive DP wave filter/obsK2', 'Gain', mat2str(K2));
    set_param('model_for_simulation/Passive DP wave filter/obsK4', 'Gain', mat2str(K4));
    set_param('model_for_simulation/Passive DP wave filter/obsK3', 'Gain', mat2str(K3));
    set_param('model_for_simulation/Passive DP wave filter/inv(T_b)', 'Gain', mat2str(T_b_inv));
    set_param('model_for_simulation/Passive DP wave filter/obsKw1', 'Gain', mat2str(Kw1));
    set_param('model_for_simulation/Passive DP wave filter/obsKw2', 'Gain', mat2str(Kw2));
    
    Setpoints = [0, 0, 0];
%     Setpoints = [2, 0, 0;
%                  0, -2, 0;
%                  0, 0, -pi/4;
%                  -2, 2, pi/4];
    cost_eta = 0;
    cost_eta_dot = 0;
    cost_nu = 0;
    cost_nu_dot = 0;
    for i=1:size(Setpoints,1)
        setpoint = Setpoints(i,:);
        set_param('model_for_simulation/Simulation inputs/Constant7', 'Value', mat2str(setpoint));
        %Simulate
        sim('model_for_simulation'); 
        
        load('results/eta.mat');
        load('results/eta_hat.mat');
        load('results/nu3.mat');
        load('results/nu_hat.mat');
        
        %Get simulation data
        eta = eta.Data;
        eta_hat = eta_hat.Data;
        nu = nu3.Data;
        nu_hat = nu_hat.Data;
        
        %eta(:,3) = 180/pi * eta(:,3)
        %eta_hat(:,3) = 180/pi * eta_hat(:,3)
        %nu(:,3) = 180/pi * nu(:,3)
        %nu_hat(:,3) = 180/pi * nu_hat(:,3)

        %Calculate norms
        eta_err = eta-eta_hat;
        %eta_err(:,3) = eta_err(:,3)*180/pi;
        eta_norm = (eta_err).^2;
        nu_norm = (nu - nu_hat).^2;
        nu_dot_norm = abs(diff(nu_hat));
        eta_dot_norm = abs(diff(eta_hat));

        cost_eta = cost_eta + sum(sum(eta_norm));
        cost_nu = cost_nu + sum(sum(nu_norm));
        cost_nu_dot = cost_nu_dot + sum(sum(nu_dot_norm));
        cost_eta_dot = cost_eta_dot + sum(sum(eta_dot_norm));
    end
    
    cost = cost_eta  + 10*cost_eta_dot + cost_nu + 10*cost_nu_dot;
    
    %write findings to file
    fileID = fopen('results/observer_params.txt','a');
    fprintf(fileID,'%f %f %f %f %f %f %f %f %f %f %f\n', x', cost_eta, 0.1*cost_eta_dot, cost_nu, cost_nu_dot, cost);
    fclose(fileID);
    
end