function filtered_sensor_data = filtering(sensor_data, filtertype)
    switch(filtertype)
        case 1 % Equiripple low pass
            
            %Pre-allocating output data
            filtered_sensor_data = [];

            % Lowpass filter properties
            Fs = 100; % Sample rate [Hz]
            Fp = 0.5; % Passband frequency [Hz]
            Fst = 15; % Stopband frequency[Hz]
            Ap = 0.5; % Passband attenuation [dB]
            Ast = 100; % Stopband attenuation [dB]
            
            % Designing equiripple lowpass FIR
            d = designfilt('lowpassfir','StopbandFrequency',Fst, ...
            'PassbandFrequency',Fp,'PassbandRipple',Ap,'StopbandAttenuation',Ast, ...
            'SampleRate',Fs,'DesignMethod','equiripple');
        
            %Estimating group delay according to filter properties
            D = floor(mean(grpdelay(d)))+1;

            % Filtering each variable
            for i = 1:length(sensor_data(1,:))
                temp = filter(d,sensor_data(:,i));       %Filtering
                filtered_sensor_data(:,i) = temp(D+1:end);    %Correcting group delay
            end
            
        case 2 % Low pass
            Fs = 100; % Sample rate [Hz]
            pf = 0.1; % Passband frequency [Hz]
            sf = 1; % Stopband frequency [Hz]
            pa = 0.5; % Passband attenuation [dB]
            sa = 100; % Stopband attenuation [dB]
            filtered_sensor_data = [lowpass(sensor_data(:,1:end), pf, Fs)];
            %filtered_sensor_data = [sensor_data(:,1), lowpass(sensor_data(:,2:end), pf, Fs)];
            
    end
end